@@ -9,12 +9,16 @@ from django.utils.html import format_html
 
 # Alliance Auth
 from allianceauth.eveonline.evelinks import eveimageserver
+from allianceauth.services.hooks import get_extension_logger
+
+# Alliance Auth (External Libs)
+from app_utils.logging import LoggerAddTag
 
 # AA Killstats
-from killstats.hooks import get_extension_logger
+from killstats import __title__
 from killstats.models.killstatsaudit import AlliancesAudit, CorporationsAudit
 
-logger = get_extension_logger(__name__)
+logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
 @admin.register(CorporationsAudit)
